@@ -1,5 +1,5 @@
 import os
-from ..core.generator import create_structure  # Use o caminho absoluto do pacote
+from pymodularizer.core.generator import create_structure  # Use o caminho absoluto do pacote
 
 def test_create_structure(tmp_path):
     structure = {
